defaultChunkDelayMs constant
int
const defaultChunkDelayMs
Delay between sending chunks (in milliseconds).
Gives the printer time to process each chunk before receiving more. Increase this if your printer drops data on large print jobs.
Implementation
static const int defaultChunkDelayMs = 5;