reset method
Clear the buffer and reset text styles.
Sends ESC @ to initialize the printer (returns to standard mode), then explicitly cancels any page mode to ensure continuous roll paper printing (no fixed page height like A4).
Implementation
List<int> reset() {
List<int> bytes = [];
bytes += cInit.codeUnits;
// Cancel page mode if active — ensures standard (continuous) mode
// for roll paper printers so there is no fixed page height.
bytes += cFormFeed.codeUnits;
// Re-initialize after form feed to clear any page mode state.
bytes += cInit.codeUnits;
_styles = PosStyles();
bytes += setGlobalCodeTable(_codeTable);
bytes += setGlobalFont(_font);
return bytes;
}